==> haskell-time-units-1.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-units.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-units
version:              1.0.0
visibility:           public
id:                   time-units-1.0.0-D1nYXpAWCQ2FSIdA8ibzEx
key:                  time-units-1.0.0-D1nYXpAWCQ2FSIdA8ibzEx
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhusre.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/time-units
synopsis:             A basic library for defining units of time as types.
description:
    In many cases, it is useful (either for error checking or documentation
    reasons) to define input and output types as having a particular unit of
    time. In addition, by creating a type class defining type units, this
    library should make it easier to separate the units of time the developer
    wants to think in versus the units of time the library author wants to
    think in.

category:             Data
abi:                  76a2f13688cb27bdf36ebdd92f51c18e
exposed:              True
exposed-modules:      Data.Time.Units
import-dirs:          /usr/lib/ghc-9.0.2/site-local/time-units-1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/time-units-1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-units
hs-libraries:         HStime-units-1.0.0-D1nYXpAWCQ2FSIdA8ibzEx
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-time-units/html/time-units.haddock
haddock-html:         /usr/share/doc/haskell-time-units/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-units-1.0.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-units.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-units
version:              1.0.0
visibility:           public
id:                   time-units-1.0.0-5ANWMnlmGbA6CL2adJPINT
key:                  time-units-1.0.0-5ANWMnlmGbA6CL2adJPINT
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhusre.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/time-units
synopsis:             A basic library for defining units of time as types.
description:
    In many cases, it is useful (either for error checking or documentation
    reasons) to define input and output types as having a particular unit of
    time. In addition, by creating a type class defining type units, this
    library should make it easier to separate the units of time the developer
    wants to think in versus the units of time the library author wants to
    think in.

category:             Data
abi:                  ad9b87375a8353c2b434e220f2aaeba0
exposed:              True
exposed-modules:      Data.Time.Units
import-dirs:          /usr/lib/ghc-9.2.8/site-local/time-units-1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/time-units-1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-units
hs-libraries:         HStime-units-1.0.0-5ANWMnlmGbA6CL2adJPINT
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-time-units/html/time-units.haddock
haddock-html:         /usr/share/doc/haskell-time-units/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
